@@ -181,7 +181,7 @@ DEFAULT_CLI_ARGS = {
             ("--project-dir",),
             dict(
                 help="optional path for the location of the playbook content directory "
-                     "(default=<private_data_dir/project)"
+                     "(default=<private_data_dir>/project)"
             ),
         ),
         (
@@ -217,6 +217,14 @@ DEFAULT_CLI_ARGS = {
                      "(status and stdout still included for other events)"
             ),
         ),
+        (
+            ("--omit-env-files",),
+            dict(
+                action="store_true",
+                dest='suppress_env_files',
+                help="Add flag to prevent the writing of the env directory"
+            ),
+        ),
         (
             ("-q", "--quiet",),
             dict(
@@ -320,54 +328,6 @@ DEFAULT_CLI_ARGS = {
                      "to prevent multiple simultaneous executions from conflicting "
                      "(default=None)"
             )
-        ),
-        (
-            ("--resource-profiling",),
-            dict(
-                dest='resource_profiling',
-                action="store_true",
-                help="Records resource utilization during playbook execution"
-            )
-        ),
-        (
-            ("--resource-profiling-base-cgroup",),
-            dict(
-                dest='resource_profiling_base_cgroup',
-                default="ansible-runner",
-                help="Top-level cgroup used to collect information on resource utilization. Defaults to ansible-runner"
-            )
-        ),
-        (
-            ("--resource-profiling-cpu-poll-interval",),
-            dict(
-                dest='resource_profiling_cpu_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between CPU polling for determining CPU usage. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-memory-poll-interval",),
-            dict(
-                dest='resource_profiling_memory_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between memory polling for determining memory usage. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-pid-poll-interval",),
-            dict(
-                dest='resource_profiling_pid_poll_interval',
-                default=0.25,
-                help="Interval (in seconds) between polling PID count for determining number of processes used. Defaults to 0.25"
-            )
-        ),
-        (
-            ("--resource-profiling-results-dir",),
-            dict(
-                dest='resource_profiling_results_dir',
-                help="Directory where profiling data files should be saved. "
-                     "Defaults to None (profiling_data folder under private data dir is used in this case)."
-            )
         )
     ),
     "modules_group": (
@@ -548,11 +508,9 @@ def add_args_to_parser(parser, args):
     """
     Traverse a tuple of argments to add to a parser
 
-    :param parser: Instance of a parser, subparser, or argument group
-    :type sys_args: argparse.ArgumentParser
+    :param argparse.ArgumentParser parser: Instance of a parser, subparser, or argument group
 
-    :param args: Tuple of tuples, format ((arg1, arg2), {'kwarg1':'val1'},)
-    :type sys_args: tuple
+    :param tuple args: Tuple of tuples, format ((arg1, arg2), {'kwarg1':'val1'},)
 
     :returns: None
     """
@@ -566,8 +524,7 @@ def main(sys_args=None):
     When the ```ansible-runner``` command is executed, this function
     is the main entry point that is called and executed.
 
-    :param sys_args: List of arguments to be parsed by the parser
-    :type sys_args: list
+    :param list sys_args: List of arguments to be parsed by the parser
 
     :returns: an instance of SystemExit
     :rtype: SystemExit
@@ -659,6 +616,14 @@ def main(sys_args=None):
         help="Receive the output of remote ansible-runner work and distribute the results"
     )
     add_args_to_parser(process_subparser, DEFAULT_CLI_ARGS['positional_args'])
+    process_subparser.add_argument(
+        "-i", "--ident",
+        default=None,
+        help=(
+            "An identifier to use as a subdirectory when saving artifacts. "
+            "Generally intended to match the --ident passed to the transmit command."
+        )
+    )
 
     # generic args for all subparsers
     add_args_to_parser(run_subparser, DEFAULT_CLI_ARGS['generic_args'])
@@ -752,7 +717,7 @@ def main(sys_args=None):
     # container group
     container_group_options = (
         "Ansible Container Options",
-        "configuation options for executing Ansible playbooks",
+        "configuration options for executing Ansible playbooks",
     )
     run_container_group = run_subparser.add_argument_group(*container_group_options)
     start_container_group = start_subparser.add_argument_group(*container_group_options)
@@ -890,15 +855,10 @@ def main(sys_args=None):
                                    container_volume_mounts=vargs.get('container_volume_mounts'),
                                    container_options=vargs.get('container_options'),
                                    directory_isolation_base_path=vargs.get('directory_isolation_base_path'),
-                                   resource_profiling=vargs.get('resource_profiling'),
-                                   resource_profiling_base_cgroup=vargs.get('resource_profiling_base_cgroup'),
-                                   resource_profiling_cpu_poll_interval=vargs.get('resource_profiling_cpu_poll_interval'),
-                                   resource_profiling_memory_poll_interval=vargs.get('resource_profiling_memory_poll_interval'),
-                                   resource_profiling_pid_poll_interval=vargs.get('resource_profiling_pid_poll_interval'),
-                                   resource_profiling_results_dir=vargs.get('resource_profiling_results_dir'),
                                    cmdline=vargs.get('cmdline'),
                                    limit=vargs.get('limit'),
-                                   streamer=streamer
+                                   streamer=streamer,
+                                   suppress_env_files=vargs.get("suppress_env_files"),
                                    )
                 try:
                     res = run(**run_options)
@@ -909,21 +869,21 @@ def main(sys_args=None):
                     else:
                         sys.stderr.write(exc)
                     return 1
-            return(res.rc)
+            return res.rc
 
     try:
         with open(pidfile, 'r') as f:
             pid = int(f.readline())
     except IOError:
-        return(1)
+        return 1
 
     if vargs.get('command') == 'stop':
         Runner.handle_termination(pid, pidfile=pidfile)
-        return (0)
+        return 0
 
     elif vargs.get('command') == 'is-alive':
         try:
             os.kill(pid, signal.SIG_DFL)
-            return(0)
+            return 0
         except OSError:
-            return(1)
+            return 1
