@@ -43,7 +43,6 @@ class Runner(object):
         # default runner mode to pexpect
         self.runner_mode = self.config.runner_mode if hasattr(self.config, 'runner_mode') else 'pexpect'
 
-        self.resource_profiling = self.config.resource_profiling if hasattr(self.config, 'resource_profiling') else False
         self.directory_isolation_path = self.config.directory_isolation_path if hasattr(self.config, 'directory_isolation_path') else None
         self.directory_isolation_cleanup = self.config.directory_isolation_cleanup if hasattr(self.config, 'directory_isolation_cleanup') else None
         self.process_isolation = self.config.process_isolation if hasattr(self.config, 'process_isolation') else None
@@ -117,9 +116,7 @@ class Runner(object):
         password_values = []
 
         self.status_callback('starting')
-        stdout_filename = os.path.join(self.config.artifact_dir, 'stdout')
         command_filename = os.path.join(self.config.artifact_dir, 'command')
-        stderr_filename = os.path.join(self.config.artifact_dir, 'stderr')
 
         try:
             os.makedirs(self.config.artifact_dir, mode=0o700)
@@ -128,7 +125,6 @@ class Runner(object):
                 pass
             else:
                 raise
-        os.close(os.open(stdout_filename, os.O_CREAT, stat.S_IRUSR | stat.S_IWUSR))
 
         job_events_path = os.path.join(self.config.artifact_dir, 'job_events')
         if not os.path.exists(job_events_path):
@@ -151,9 +147,17 @@ class Runner(object):
         else:
             suppress_ansible_output = False
 
-        stdout_handle = codecs.open(stdout_filename, 'w', encoding='utf-8')
+        if not self.config.suppress_output_file:
+            stdout_filename = os.path.join(self.config.artifact_dir, 'stdout')
+            stderr_filename = os.path.join(self.config.artifact_dir, 'stderr')
+            os.close(os.open(stdout_filename, os.O_CREAT, stat.S_IRUSR | stat.S_IWUSR))
+            stdout_handle = codecs.open(stdout_filename, 'w', encoding='utf-8')
+            stderr_handle = codecs.open(stderr_filename, 'w', encoding='utf-8')
+        else:
+            stdout_handle = None
+            stderr_handle = None
+
         stdout_handle = OutputEventFilter(stdout_handle, self.event_callback, suppress_ansible_output, output_json=self.config.json_mode)
-        stderr_handle = codecs.open(stderr_filename, 'w', encoding='utf-8')
         stderr_handle = OutputEventFilter(stderr_handle, self.event_callback, suppress_ansible_output, output_json=self.config.json_mode)
 
         if self.runner_mode == 'pexpect' and not isinstance(self.config.expect_passwords, collections.OrderedDict):
@@ -195,29 +199,6 @@ class Runner(object):
             for k, v in pexpect_env.items()
         }
 
-        # Prepare to collect performance data
-        if self.resource_profiling:
-            cgroup_path = '{0}/{1}'.format(self.config.resource_profiling_base_cgroup, self.config.ident)
-
-            import getpass
-            import grp
-            user = getpass.getuser()
-            group = grp.getgrgid(os.getgid()).gr_name
-
-            cmd = ['cgcreate',
-                   '-a', f'{user}:{group}',
-                   '-t', f'{user}:{group}',
-                   '-g', f'cpuacct,memory,pids:{cgroup_path}',
-                   ]
-            proc = Popen(cmd, stdout=PIPE, stderr=PIPE)
-            _, stderr = proc.communicate()
-            if proc.returncode:
-                # Unable to create cgroup
-                logger.error('Unable to create cgroup: {}'.format(stderr))
-                raise RuntimeError('Unable to create cgroup: {}'.format(stderr))
-            else:
-                logger.info("Created cgroup '{}'".format(cgroup_path))
-
         self.status_callback('running')
         self.last_stdout_update = time.time()
 
@@ -281,7 +262,7 @@ class Runner(object):
                 stderr_response = traceback.format_exc()
                 self.rc = 254
                 self.errored = True
-                logger.debug("received execption: {exc}".format(exc=str(exc)))
+                logger.debug("received exception: {exc}".format(exc=str(exc)))
 
             if self.timed_out or self.errored:
                 self.kill_container()
@@ -294,6 +275,9 @@ class Runner(object):
                 if isinstance(stderr_response, bytes):
                     stderr_response = stderr_response.decode()
                 stderr_handle.write(stderr_response)
+
+            stdout_handle.close()
+            stderr_handle.close()
         else:
             try:
                 child = pexpect.spawn(
@@ -355,8 +339,8 @@ class Runner(object):
                     Runner.handle_termination(child.pid, is_cancel=False)
                     self.timed_out = True
 
-            stdout_handle.flush()
             stdout_handle.close()
+            stderr_handle.close()
             child.close()
             self.rc = child.exitstatus if not (self.timed_out or self.canceled) else 254
 
@@ -393,13 +377,6 @@ class Runner(object):
                         raise
                 return True
             _delete()
-        if self.resource_profiling:
-            cmd = ['cgdelete', '-g', f'cpuacct,memory,pids:{cgroup_path}']
-            proc = Popen(cmd, stdout=PIPE, stderr=PIPE)
-            _, stderr = proc.communicate()
-            if proc.returncode:
-                logger.error('Failed to delete cgroup: {}'.format(stderr))
-                raise RuntimeError('Failed to delete cgroup: {}'.format(stderr))
 
         if self.artifacts_handler is not None:
             try:
@@ -546,7 +523,7 @@ class Runner(object):
     @classmethod
     def handle_termination(cls, pid, pidfile=None, is_cancel=True):
         '''
-        Internal method to terminate a subprocess spawned by `pexpect` representing an invocation of runner.
+        Internal method to terminate a subprocess spawned by ``pexpect`` representing an invocation of runner.
 
         :param pid:       the process id of the running the job.
         :param pidfile:   the daemon's PID file
