@@ -11,15 +11,21 @@ from ansible_runner import Runner
 
 from ansible_runner.exceptions import AnsibleRunnerException
 
+from test.utils.common import iterate_timeout
 
+
+@pytest.mark.xfail(reason='Test is unstable')
 def test_password_prompt(rc):
     rc.command = [sys.executable, '-c' 'import time; print(input("Password: "))']
     rc.expect_passwords[re.compile(r'Password:\s*?$', re.M)] = '1234'
     status, exitcode = Runner(config=rc).run()
     assert status == 'successful'
     assert exitcode == 0
-    with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
-        assert '1234' in f.read()
+    # stdout file can be subject to a race condition
+    for _ in iterate_timeout(30.0, 'stdout file to be written with 1234 in it', interval=0.2):
+        with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
+            if '1234' in f.read():
+                break
 
 
 def test_run_command(rc):
@@ -182,7 +188,7 @@ def test_run_command_ansible(rc):
     assert exitcode == 0
     assert list(runner.events) != []
     assert runner.stats != {}
-    assert list(runner.host_events('localhost')) != []
+    assert list(runner.host_events('localhost')) != [], repr(list(runner.events))
     stdout = runner.stdout
     assert stdout.read() != ""
 
@@ -270,5 +276,8 @@ def test_set_extra_vars(rc):
     rc.prepare()
     runner = Runner(config=rc)
     status, exitcode = runner.run()
-    with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
-        assert 'hello there' in f.read()
+    # stdout file can be subject to a race condition
+    for _ in iterate_timeout(30.0, 'stdout file to be written with "hello there" in it', interval=0.2):
+        with open(os.path.join(rc.artifact_dir, 'stdout')) as f:
+            if 'hello there' in f.read():
+                break
